
-------------------------------------------------------------------------------
-- Create ACCT table
-------------------------------------------------------------------------------

CREATE TABLE ACCT
(
	ACCT_ID              INTEGER NOT NULL ,
	APP_DB_ID            INTEGER NOT NULL ,
	USR_ID               VARCHAR2(25) NOT NULL ,
	PW_TXT               VARCHAR2(50) NOT NULL ,
	ACCT_DS              VARCHAR2(150) NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_ACCT ON ACCT
(ACCT_ID   ASC);

ALTER TABLE ACCT
	ADD CONSTRAINT  PK_ACCT PRIMARY KEY (ACCT_ID);

ALTER TABLE ACCT
	MODIFY CRT_BY_USR_ID DEFAULT USER;

CREATE INDEX FX01_ACCT ON ACCT
(APP_DB_ID   ASC);

-------------------------------------------------------------------------------
-- Create APP table
-------------------------------------------------------------------------------

CREATE TABLE APP
(
	APP_ID               INTEGER NOT NULL ,
	APP_NME              VARCHAR2(50) NOT NULL ,
	APP_DS               VARCHAR2(150) NOT NULL ,
	END_DT               DATE NULL ,
	STR_DT               DATE NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_APP ON APP
(APP_ID   ASC);

ALTER TABLE APP
	ADD CONSTRAINT  PK_APP PRIMARY KEY (APP_ID);

ALTER TABLE APP
	MODIFY CRT_BY_USR_ID DEFAULT USER;

-------------------------------------------------------------------------------
-- Create APP_DB table
-------------------------------------------------------------------------------

CREATE TABLE APP_DB
(
	APP_DB_ID            INTEGER NOT NULL ,
	APP_ID               INTEGER NOT NULL ,
	DB_INST_NME          VARCHAR2(50) NOT NULL ,
	STR_UP_PROC_TXT      VARCHAR2(4000) NULL ,
	SHUT_DOWN_PROC_TXT   VARCHAR2(4000) NULL ,
	LOGIN_PROC_TXT       VARCHAR2(4000) NULL ,
	END_DT               DATE NULL ,
	STR_DT               DATE NOT NULL ,
	ENV_CD               VARCHAR2(10) NOT NULL ,
	SRVC_LVL_AGRMT_CD    VARCHAR2(10) NOT NULL ,
	TBLSP_NME            VARCHAR2(50) NULL ,
	CURR_SIZE_BYTES_NBR  NUMBER(15,2) NULL ,
	BU_PROC_TXT          VARCHAR2(4000) NULL ,
	DBMS_ID              INTEGER NOT NULL ,
	APP_DB_STS_CD        VARCHAR2(10) NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_APP_DB ON APP_DB
(APP_DB_ID   ASC);

ALTER TABLE APP_DB
	ADD CONSTRAINT  PK_APP_DB PRIMARY KEY (APP_DB_ID);

ALTER TABLE APP_DB
	MODIFY CRT_BY_USR_ID DEFAULT USER;

CREATE INDEX FX01_APP_DB ON APP_DB
(APP_ID   ASC);

CREATE INDEX FX02_APP_DB ON APP_DB
(ENV_CD   ASC);

CREATE INDEX FX03_APP_DB ON APP_DB
(SRVC_LVL_AGRMT_CD   ASC);

CREATE INDEX FX04_APP_DB ON APP_DB
(DBMS_ID   ASC);

CREATE INDEX FX05_APP_DB ON APP_DB
(APP_DB_STS_CD   ASC);

-------------------------------------------------------------------------------
-- Create APP_DB_HST table
-------------------------------------------------------------------------------

CREATE TABLE APP_DB_HST
(
	APP_DB_HST_ID        INTEGER NOT NULL ,
	APP_HST_ID           INTEGER NOT NULL ,
	APP_DB_ID            INTEGER NOT NULL ,
	STANDBY_IND          CHAR(1) NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_APP_DB_HST ON APP_DB_HST
(APP_DB_HST_ID   ASC);

ALTER TABLE APP_DB_HST
	ADD CONSTRAINT  PK_APP_DB_HST PRIMARY KEY (APP_DB_HST_ID);

ALTER TABLE APP_DB_HST
	MODIFY STANDBY_IND CONSTRAINT  INDICATOR_VALUE_1849699136 CHECK (STANDBY_IND IN ('Y', 'N'));

ALTER TABLE APP_DB_HST
	MODIFY STANDBY_IND DEFAULT 'N';

ALTER TABLE APP_DB_HST
	MODIFY CRT_BY_USR_ID DEFAULT USER;

CREATE INDEX FX01_APP_DB_HST ON APP_DB_HST
(APP_HST_ID   ASC);

CREATE INDEX FX02_APP_DB_HST ON APP_DB_HST
(APP_DB_ID   ASC);

-------------------------------------------------------------------------------
-- Create APP_DB_NOTE table
-------------------------------------------------------------------------------

CREATE TABLE APP_DB_NOTE
(
	APP_DB_NOTE_ID       INTEGER NOT NULL ,
	APP_DB_ID            INTEGER NOT NULL ,
	NOTE_TXT             VARCHAR2(4000) NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_APP_DB_NOTE ON APP_DB_NOTE
(APP_DB_NOTE_ID   ASC);

ALTER TABLE APP_DB_NOTE
	ADD CONSTRAINT  PK_APP_DB_NOTE PRIMARY KEY (APP_DB_NOTE_ID);

ALTER TABLE APP_DB_NOTE
	MODIFY CRT_BY_USR_ID DEFAULT USER;

CREATE INDEX FX01_APP_DB_NOTE ON APP_DB_NOTE
(APP_DB_ID   ASC);

-------------------------------------------------------------------------------
-- Create APP_DB_STS table
-------------------------------------------------------------------------------

CREATE TABLE APP_DB_STS
(
	APP_DB_STS_CD        VARCHAR2(10) NOT NULL ,
	APP_DB_STS_DS        VARCHAR2(150) NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_APP_DB_STS ON APP_DB_STS
(APP_DB_STS_CD   ASC);

ALTER TABLE APP_DB_STS
	ADD CONSTRAINT  PK_APP_DB_STS PRIMARY KEY (APP_DB_STS_CD);

ALTER TABLE APP_DB_STS
	MODIFY CRT_BY_USR_ID DEFAULT USER;

-------------------------------------------------------------------------------
-- Create APP_HST table
-------------------------------------------------------------------------------

CREATE TABLE APP_HST
(
	APP_HST_ID           INTEGER NOT NULL ,
	APP_HST_NME          VARCHAR2(256) NOT NULL ,
	LOC_TXT              VARCHAR2(4000) NULL ,
	CPU_CORE_COUNT       INTEGER NULL ,
	OS_CD                VARCHAR2(10) NOT NULL ,
	EDA_GRP_ID           INTEGER NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_APP_HST ON APP_HST
(APP_HST_ID   ASC);

ALTER TABLE APP_HST
	ADD CONSTRAINT  PK_APP_HST PRIMARY KEY (APP_HST_ID);

ALTER TABLE APP_HST
	MODIFY CRT_BY_USR_ID DEFAULT USER;

CREATE INDEX FX01_APP_HST ON APP_HST
(OS_CD   ASC);

CREATE INDEX FX02_APP_HST ON APP_HST
(EDA_GRP_ID   ASC);

-------------------------------------------------------------------------------
-- Create APP_STAFF table
-------------------------------------------------------------------------------

CREATE TABLE APP_STAFF
(
	APP_STAFF_ID         INTEGER NOT NULL ,
	APP_ID               INTEGER NULL ,
	STAFF_ID             INTEGER NOT NULL ,
	STAFF_ROLE_CD        VARCHAR2(10) NOT NULL ,
	STR_DT               DATE NOT NULL ,
	END_DT               DATE NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_APP_STAFF ON APP_STAFF
(APP_STAFF_ID   ASC);

ALTER TABLE APP_STAFF
	ADD CONSTRAINT  PK_APP_STAFF PRIMARY KEY (APP_STAFF_ID);

ALTER TABLE APP_STAFF
	MODIFY CRT_BY_USR_ID DEFAULT USER;

CREATE INDEX FX01_APP_STAFF ON APP_STAFF
(APP_ID   ASC);

CREATE INDEX FX02_APP_STAFF ON APP_STAFF
(STAFF_ID   ASC);

CREATE INDEX FX03_APP_STAFF ON APP_STAFF
(STAFF_ROLE_CD   ASC);

-------------------------------------------------------------------------------
-- Create AUTHRZD_REQSTR table
-------------------------------------------------------------------------------

CREATE TABLE AUTHRZD_REQSTR
(
	AUTHRZD_REQSTR_ID    INTEGER NOT NULL ,
	FRST_NME             VARCHAR2(50) NULL ,
	LAST_NME             VARCHAR2(50) NULL ,
	EMAIL_ADR            VARCHAR2(320) NOT NULL ,
	TEL_NBR              VARCHAR2(14) NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_AUTHRZD_REQSTR ON AUTHRZD_REQSTR
(AUTHRZD_REQSTR_ID   ASC);

ALTER TABLE AUTHRZD_REQSTR
	ADD CONSTRAINT  PK_AUTHRZD_REQSTR PRIMARY KEY (AUTHRZD_REQSTR_ID);

ALTER TABLE AUTHRZD_REQSTR
	MODIFY CRT_BY_USR_ID DEFAULT USER;

-------------------------------------------------------------------------------
-- Create CAL_EVENT_TYP table
-------------------------------------------------------------------------------

CREATE TABLE CAL_EVENT_TYP
(
	CAL_EVENT__CD        VARCHAR2(10) NOT NULL ,
	CAL_EVENT_NME        VARCHAR2(50) NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_CAL_EVENT_TYP ON CAL_EVENT_TYP
(CAL_EVENT__CD   ASC);

ALTER TABLE CAL_EVENT_TYP
	ADD CONSTRAINT  PK_CAL_EVENT_TYP PRIMARY KEY (CAL_EVENT__CD);

ALTER TABLE CAL_EVENT_TYP
	MODIFY CRT_BY_USR_ID DEFAULT USER;

-------------------------------------------------------------------------------
-- Create DB_INST table
-------------------------------------------------------------------------------

CREATE TABLE DB_INST
(
	DB_INST_ID           INTEGER NOT NULL ,
	DB_INST_NME          VARCHAR2(50) NOT NULL ,
	APP_DB_HST_ID        INTEGER NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_DB_INST ON DB_INST
(DB_INST_ID   ASC);

ALTER TABLE DB_INST
	ADD CONSTRAINT  PK_DB_INST PRIMARY KEY (DB_INST_ID);

ALTER TABLE DB_INST
	MODIFY CRT_BY_USR_ID DEFAULT USER;

CREATE INDEX FX01_DB_INST ON DB_INST
(APP_DB_HST_ID   ASC);

-------------------------------------------------------------------------------
-- Create DB_INST_SRVC table
-------------------------------------------------------------------------------

CREATE TABLE DB_INST_SRVC
(
	DB_INST_SRVC_ID      INTEGER NOT NULL ,
	DB_INST_ID           INTEGER NOT NULL ,
	DB_INST_SRVC_NME     VARCHAR2(100) NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_DB_INST_SRVC ON DB_INST_SRVC
(DB_INST_SRVC_ID   ASC);

ALTER TABLE DB_INST_SRVC
	ADD CONSTRAINT  PK_DB_INST_SRVC PRIMARY KEY (DB_INST_SRVC_ID);

ALTER TABLE DB_INST_SRVC
	MODIFY CRT_BY_USR_ID DEFAULT USER;

CREATE INDEX FX01_DB_INST_SRVC ON DB_INST_SRVC
(DB_INST_ID   ASC);

-------------------------------------------------------------------------------
-- Create DBMS table
-------------------------------------------------------------------------------

CREATE TABLE DBMS
(
	DBMS_ID              INTEGER NOT NULL ,
	DBMS_NME             VARCHAR2(75) NOT NULL ,
	VER_NBR              VARCHAR2(100) NOT NULL ,
	EDA_GRP_ID           INTEGER NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_DBMS ON DBMS
(DBMS_ID   ASC);

ALTER TABLE DBMS
	ADD CONSTRAINT  PK_DBMS PRIMARY KEY (DBMS_ID);

ALTER TABLE DBMS
	MODIFY CRT_BY_USR_ID DEFAULT USER;

CREATE INDEX FX01_DBMS ON DBMS
(EDA_GRP_ID   ASC);

-------------------------------------------------------------------------------
-- Create EDA_GRP table
-------------------------------------------------------------------------------

CREATE TABLE EDA_GRP
(
	EDA_GRP_ID           INTEGER NOT NULL ,
	EDA_GRP_NM           VARCHAR2(50) NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_EDA_GRP ON EDA_GRP
(EDA_GRP_ID   ASC);

ALTER TABLE EDA_GRP
	ADD CONSTRAINT  PK_EDA_GRP PRIMARY KEY (EDA_GRP_ID);

ALTER TABLE EDA_GRP
	MODIFY CRT_BY_USR_ID DEFAULT USER;

-------------------------------------------------------------------------------
-- Create ENV table
-------------------------------------------------------------------------------

CREATE TABLE ENV
(
	ENV_CD               VARCHAR2(10) NOT NULL ,
	ENV_DS               VARCHAR2(150) NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_ENV ON ENV
(ENV_CD   ASC);

ALTER TABLE ENV
	ADD CONSTRAINT  PK_ENV PRIMARY KEY (ENV_CD);

ALTER TABLE ENV
	MODIFY CRT_BY_USR_ID DEFAULT USER;

-------------------------------------------------------------------------------
-- Create EVENT table
-------------------------------------------------------------------------------

CREATE TABLE EVENT
(
	EVENT_ID             INTEGER NOT NULL ,
	APP_DB_ID            INTEGER NOT NULL ,
	TECH_EVENT_TYP_ID    INTEGER NOT NULL ,
	SUMRY_TXT            VARCHAR2(4000) NOT NULL ,
	STR_TS               TIMESTAMP NOT NULL ,
	END_TS               TIMESTAMP NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_EVENT ON EVENT
(EVENT_ID   ASC);

ALTER TABLE EVENT
	ADD CONSTRAINT  PK_EVENT PRIMARY KEY (EVENT_ID);

ALTER TABLE EVENT
	MODIFY CRT_BY_USR_ID DEFAULT USER;

CREATE INDEX FX01_EVENT ON EVENT
(APP_DB_ID   ASC);

CREATE INDEX FX02_EVENT ON EVENT
(TECH_EVENT_TYP_ID   ASC);

-------------------------------------------------------------------------------
-- Create OS table
-------------------------------------------------------------------------------

CREATE TABLE OS
(
	OS_CD                VARCHAR2(10) NOT NULL ,
	OS_NME               VARCHAR2(50) NULL ,
	VER_NBR              VARCHAR2(100) NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_OS ON OS
(OS_CD   ASC);

ALTER TABLE OS
	ADD CONSTRAINT  PK_OS PRIMARY KEY (OS_CD);

ALTER TABLE OS
	MODIFY CRT_BY_USR_ID DEFAULT USER;

-------------------------------------------------------------------------------
-- Create PROVNG table
-------------------------------------------------------------------------------

CREATE TABLE PROVNG
(
	PROVNG_ID            INTEGER NOT NULL ,
	APP_DB_ID            INTEGER NOT NULL ,
	AUTHRZD_REQSTR_ID    INTEGER NOT NULL ,
	PROVNG_REQST_TS      TIMESTAMP NOT NULL ,
	COMNT_TXT            VARCHAR2(4000) NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_PROVNG ON PROVNG
(PROVNG_ID   ASC);

ALTER TABLE PROVNG
	ADD CONSTRAINT  PK_PROVNG PRIMARY KEY (PROVNG_ID);

ALTER TABLE PROVNG
	MODIFY CRT_BY_USR_ID DEFAULT USER;

CREATE INDEX FX01_PROVNG ON PROVNG
(APP_DB_ID   ASC);

CREATE INDEX FX02_PROVNG ON PROVNG
(AUTHRZD_REQSTR_ID   ASC);

-------------------------------------------------------------------------------
-- Create PROVNG_REQST table
-------------------------------------------------------------------------------

CREATE TABLE PROVNG_REQST
(
	PROVNG_REQST_ID      INTEGER NOT NULL ,
	PROVNG_ID            INTEGER NOT NULL ,
	RQSTD_SIZE_COUNT     NUMBER(15,2) NOT NULL ,
	COMNT_TXT            VARCHAR2(4000) NULL ,
	PROVNG_REQST_TYP_CD  VARCHAR2(10) NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_PROVNG_REQST ON PROVNG_REQST
(PROVNG_REQST_ID   ASC);

ALTER TABLE PROVNG_REQST
	ADD CONSTRAINT  PK_PROVNG_REQST PRIMARY KEY (PROVNG_REQST_ID);

ALTER TABLE PROVNG_REQST
	MODIFY CRT_BY_USR_ID DEFAULT USER;

CREATE INDEX FX01_PROVNG_REQST ON PROVNG_REQST
(PROVNG_ID   ASC);

CREATE INDEX FX02_PROVNG_REQST ON PROVNG_REQST
(PROVNG_REQST_TYP_CD   ASC);

-------------------------------------------------------------------------------
-- Create PROVNG_REQST_TYP table
-------------------------------------------------------------------------------

CREATE TABLE PROVNG_REQST_TYP
(
	PROVNG_REQST_TYP_CD  VARCHAR2(10) NOT NULL ,
	PROVNG_REQST_TYP_DS  VARCHAR2(150) NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_PROVNG_REQST_TYP ON PROVNG_REQST_TYP
(PROVNG_REQST_TYP_CD   ASC);

ALTER TABLE PROVNG_REQST_TYP
	ADD CONSTRAINT  PK_PROVNG_REQST_TYP PRIMARY KEY (PROVNG_REQST_TYP_CD);

ALTER TABLE PROVNG_REQST_TYP
	MODIFY CRT_BY_USR_ID DEFAULT USER;

-------------------------------------------------------------------------------
-- Create SRVC_LVL_AGRMT table
-------------------------------------------------------------------------------

CREATE TABLE SRVC_LVL_AGRMT
(
	SRVC_LVL_AGRMT_CD    VARCHAR2(10) NOT NULL ,
	SRVC_LVL_AGRMT_DS    VARCHAR2(150) NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_SRVC_LVL_AGRMT ON SRVC_LVL_AGRMT
(SRVC_LVL_AGRMT_CD   ASC);

ALTER TABLE SRVC_LVL_AGRMT
	ADD CONSTRAINT  PK_SRVC_LVL_AGRMT PRIMARY KEY (SRVC_LVL_AGRMT_CD);

ALTER TABLE SRVC_LVL_AGRMT
	MODIFY CRT_BY_USR_ID DEFAULT USER;

-------------------------------------------------------------------------------
-- Create STAFF table
-------------------------------------------------------------------------------

CREATE TABLE STAFF
(
	STAFF_ID             INTEGER NOT NULL ,
	FRST_NME             VARCHAR2(50) NULL ,
	LAST_NME             VARCHAR2(50) NULL ,
	STAFF_ROLE_CD        VARCHAR2(10) NOT NULL ,
	END_DT               DATE NULL ,
	STR_DT               DATE NOT NULL ,
	WRK_TEL_NBR          VARCHAR2(14) NULL ,
	CELL_TEL_NBR         VARCHAR2(14) NULL ,
	TEAM_CD              VARCHAR2(10) NOT NULL ,
	EDA_GRP_ID           INTEGER NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_STAFF ON STAFF
(STAFF_ID   ASC);

ALTER TABLE STAFF
	ADD CONSTRAINT  PK_STAFF PRIMARY KEY (STAFF_ID);

ALTER TABLE STAFF
	MODIFY CRT_BY_USR_ID DEFAULT USER;

CREATE INDEX FX01_STAFF ON STAFF
(STAFF_ROLE_CD   ASC);

CREATE INDEX FX02_STAFF ON STAFF
(TEAM_CD   ASC);

CREATE INDEX FX03_STAFF ON STAFF
(EDA_GRP_ID   ASC);

-------------------------------------------------------------------------------
-- Create STAFF_CAL table
-------------------------------------------------------------------------------

CREATE TABLE STAFF_CAL
(
	STAFF_CAL_EVENT_ID   INTEGER NOT NULL ,
	EDA_GRP_ID           INTEGER NOT NULL ,
	STAFF_ID             INTEGER NOT NULL ,
	STR_EVENT_DT         DATE NOT NULL ,
	CAL_EVENT__CD        VARCHAR2(10) NOT NULL ,
	END_EVENT_DT         DATE NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_STAFF_CAL ON STAFF_CAL
(STAFF_CAL_EVENT_ID   ASC);

ALTER TABLE STAFF_CAL
	ADD CONSTRAINT  PK_STAFF_CAL PRIMARY KEY (STAFF_CAL_EVENT_ID);

ALTER TABLE STAFF_CAL
	MODIFY CRT_BY_USR_ID DEFAULT USER;

CREATE INDEX FX01_STAFF_CAL ON STAFF_CAL
(EDA_GRP_ID   ASC);

CREATE INDEX FX02_STAFF_CAL ON STAFF_CAL
(STAFF_ID   ASC);

CREATE INDEX FX03_STAFF_CAL ON STAFF_CAL
(CAL_EVENT__CD   ASC);

-------------------------------------------------------------------------------
-- Create STAFF_EVENT table
-------------------------------------------------------------------------------

CREATE TABLE STAFF_EVENT
(
	STAFF_EVENT_ID       INTEGER NOT NULL ,
	STAFF_ID             INTEGER NULL ,
	EVENT_ID             INTEGER NULL ,
	END_TS               TIMESTAMP NULL ,
	STR_TS               TIMESTAMP NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_STAFF_EVENT ON STAFF_EVENT
(STAFF_EVENT_ID   ASC);

ALTER TABLE STAFF_EVENT
	ADD CONSTRAINT  PK_STAFF_EVENT PRIMARY KEY (STAFF_EVENT_ID);

ALTER TABLE STAFF_EVENT
	MODIFY CRT_BY_USR_ID DEFAULT USER;

CREATE INDEX FX01_STAFF_EVENT ON STAFF_EVENT
(STAFF_ID   ASC);

CREATE INDEX FX02_STAFF_EVENT ON STAFF_EVENT
(EVENT_ID   ASC);

-------------------------------------------------------------------------------
-- Create STAFF_ROLE table
-------------------------------------------------------------------------------

CREATE TABLE STAFF_ROLE
(
	STAFF_ROLE_CD        VARCHAR2(10) NOT NULL ,
	STAFF_ROLE_DS        VARCHAR2(150) NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_STAFF_ROLE ON STAFF_ROLE
(STAFF_ROLE_CD   ASC);

ALTER TABLE STAFF_ROLE
	ADD CONSTRAINT  PK_STAFF_ROLE PRIMARY KEY (STAFF_ROLE_CD);

ALTER TABLE STAFF_ROLE
	MODIFY CRT_BY_USR_ID DEFAULT USER;

-------------------------------------------------------------------------------
-- Create TEAM table
-------------------------------------------------------------------------------

CREATE TABLE TEAM
(
	TEAM_CD              VARCHAR2(10) NOT NULL ,
	TEAM_NME             VARCHAR2(50) NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_TEAM ON TEAM
(TEAM_CD   ASC);

ALTER TABLE TEAM
	ADD CONSTRAINT  PK_TEAM PRIMARY KEY (TEAM_CD);

ALTER TABLE TEAM
	MODIFY CRT_BY_USR_ID DEFAULT USER;

-------------------------------------------------------------------------------
-- Create TECH_EVENT_TYP table
-------------------------------------------------------------------------------

CREATE TABLE TECH_EVENT_TYP
(
	TECH_EVENT_TYP_ID    INTEGER NOT NULL ,
	TECH_EVENT_TYP_DS    VARCHAR2(150) NOT NULL ,
	PLANNED_IND          CHAR(1) NOT NULL ,
	CRT_BY_USR_ID        VARCHAR2(50) NOT NULL ,
	CRT_TS               TIMESTAMP NOT NULL ,
	UPDT_BY_USR_ID       VARCHAR2(50) NULL ,
	UPDT_TS              TIMESTAMP NULL 
);

CREATE UNIQUE INDEX PK_TECH_EVENT_TYP ON TECH_EVENT_TYP
(TECH_EVENT_TYP_ID   ASC);

ALTER TABLE TECH_EVENT_TYP
	ADD CONSTRAINT  PK_TECH_EVENT_TYP PRIMARY KEY (TECH_EVENT_TYP_ID);

ALTER TABLE TECH_EVENT_TYP
	MODIFY PLANNED_IND CONSTRAINT  INDICATOR_VALUE_16243467 CHECK (PLANNED_IND IN ('Y', 'N'));

ALTER TABLE TECH_EVENT_TYP
	MODIFY PLANNED_IND DEFAULT 'Y';

ALTER TABLE TECH_EVENT_TYP
	MODIFY CRT_BY_USR_ID DEFAULT USER;

ALTER TABLE ACCT
	ADD (CONSTRAINT FK01_APP_DB FOREIGN KEY (APP_DB_ID) REFERENCES APP_DB (APP_DB_ID));

ALTER TABLE APP_DB
	ADD (CONSTRAINT FK01_APP FOREIGN KEY (APP_ID) REFERENCES APP (APP_ID));

ALTER TABLE APP_DB
	ADD (CONSTRAINT FK01_ENV FOREIGN KEY (ENV_CD) REFERENCES ENV (ENV_CD));

ALTER TABLE APP_DB
	ADD (CONSTRAINT FK01_SRVC_LVL_AGRMT FOREIGN KEY (SRVC_LVL_AGRMT_CD) REFERENCES SRVC_LVL_AGRMT (SRVC_LVL_AGRMT_CD));

ALTER TABLE APP_DB
	ADD (CONSTRAINT FK01_DBMS FOREIGN KEY (DBMS_ID) REFERENCES DBMS (DBMS_ID));

ALTER TABLE APP_DB
	ADD (CONSTRAINT FK01_APP_DB_STS FOREIGN KEY (APP_DB_STS_CD) REFERENCES APP_DB_STS (APP_DB_STS_CD));

ALTER TABLE APP_DB_HST
	ADD (CONSTRAINT FK01_APP_HST FOREIGN KEY (APP_HST_ID) REFERENCES APP_HST (APP_HST_ID));

ALTER TABLE APP_DB_HST
	ADD (CONSTRAINT FK02_APP_DB FOREIGN KEY (APP_DB_ID) REFERENCES APP_DB (APP_DB_ID));

ALTER TABLE APP_DB_NOTE
	ADD (CONSTRAINT FK04_APP_DB FOREIGN KEY (APP_DB_ID) REFERENCES APP_DB (APP_DB_ID));

ALTER TABLE APP_HST
	ADD (CONSTRAINT FK01_OS FOREIGN KEY (OS_CD) REFERENCES OS (OS_CD));

ALTER TABLE APP_HST
	ADD (CONSTRAINT FK04_EDA_GRP FOREIGN KEY (EDA_GRP_ID) REFERENCES EDA_GRP (EDA_GRP_ID));

ALTER TABLE APP_STAFF
	ADD (CONSTRAINT FK02_APP FOREIGN KEY (APP_ID) REFERENCES APP (APP_ID) ON DELETE SET NULL);

ALTER TABLE APP_STAFF
	ADD (CONSTRAINT FK01_STAFF FOREIGN KEY (STAFF_ID) REFERENCES STAFF (STAFF_ID));

ALTER TABLE APP_STAFF
	ADD (CONSTRAINT FK01_STAFF_ROLE FOREIGN KEY (STAFF_ROLE_CD) REFERENCES STAFF_ROLE (STAFF_ROLE_CD));

ALTER TABLE DB_INST
	ADD (CONSTRAINT FK01_APP_DB_HST FOREIGN KEY (APP_DB_HST_ID) REFERENCES APP_DB_HST (APP_DB_HST_ID) ON DELETE SET NULL);

ALTER TABLE DB_INST_SRVC
	ADD (CONSTRAINT FK02_DB_INST FOREIGN KEY (DB_INST_ID) REFERENCES DB_INST (DB_INST_ID));

ALTER TABLE DBMS
	ADD (CONSTRAINT FK01_EDA_GRP FOREIGN KEY (EDA_GRP_ID) REFERENCES EDA_GRP (EDA_GRP_ID));

ALTER TABLE EVENT
	ADD (CONSTRAINT FK03_APP_DB FOREIGN KEY (APP_DB_ID) REFERENCES APP_DB (APP_DB_ID));

ALTER TABLE EVENT
	ADD (CONSTRAINT FK01_TECH_EVENT_TYP FOREIGN KEY (TECH_EVENT_TYP_ID) REFERENCES TECH_EVENT_TYP (TECH_EVENT_TYP_ID));

ALTER TABLE PROVNG
	ADD (CONSTRAINT FK05_APP_DB FOREIGN KEY (APP_DB_ID) REFERENCES APP_DB (APP_DB_ID));

ALTER TABLE PROVNG
	ADD (CONSTRAINT FK01_AUTHRZD_REQSTR FOREIGN KEY (AUTHRZD_REQSTR_ID) REFERENCES AUTHRZD_REQSTR (AUTHRZD_REQSTR_ID));

ALTER TABLE PROVNG_REQST
	ADD (CONSTRAINT FK01_PROVNG FOREIGN KEY (PROVNG_ID) REFERENCES PROVNG (PROVNG_ID));

ALTER TABLE PROVNG_REQST
	ADD (CONSTRAINT FK01_PROVNG_REQST_TYP FOREIGN KEY (PROVNG_REQST_TYP_CD) REFERENCES PROVNG_REQST_TYP (PROVNG_REQST_TYP_CD));

ALTER TABLE STAFF
	ADD (CONSTRAINT FK02_STAFF_ROLE FOREIGN KEY (STAFF_ROLE_CD) REFERENCES STAFF_ROLE (STAFF_ROLE_CD));

ALTER TABLE STAFF
	ADD (CONSTRAINT FK01_TEAM FOREIGN KEY (TEAM_CD) REFERENCES TEAM (TEAM_CD));

ALTER TABLE STAFF
	ADD (CONSTRAINT FK02_EDA_GRP FOREIGN KEY (EDA_GRP_ID) REFERENCES EDA_GRP (EDA_GRP_ID));

ALTER TABLE STAFF_CAL
	ADD (CONSTRAINT FK03_EDA_GRP FOREIGN KEY (EDA_GRP_ID) REFERENCES EDA_GRP (EDA_GRP_ID));

ALTER TABLE STAFF_CAL
	ADD (CONSTRAINT FK02_STAFF FOREIGN KEY (STAFF_ID) REFERENCES STAFF (STAFF_ID));

ALTER TABLE STAFF_CAL
	ADD (CONSTRAINT FK01_CAL_EVENT_TYP FOREIGN KEY (CAL_EVENT__CD) REFERENCES CAL_EVENT_TYP (CAL_EVENT__CD));

ALTER TABLE STAFF_EVENT
	ADD (CONSTRAINT FK03_STAFF FOREIGN KEY (STAFF_ID) REFERENCES STAFF (STAFF_ID) ON DELETE SET NULL);

ALTER TABLE STAFF_EVENT
	ADD (CONSTRAINT FK01_EVENT FOREIGN KEY (EVENT_ID) REFERENCES EVENT (EVENT_ID) ON DELETE SET NULL);
